@@ -189,7 +189,7 @@ public class CDF2Json implements CDFConstants {
     private static String item8 = "GlobalAttributes";
     private static String item9 = "VariableAttributes";
     private static String separator = System.getProperty("file.separator");
-private static long numDimsN;
+
     public static void main(String[] args) throws Exception {
 
         try {
@@ -738,7 +738,7 @@ private static long numDimsN;
             dimSizes         = v.getDimSizes();
             dimVariances     = v.getDimVariances();
 
-//            long numDimsN;
+            long numDimsN;
             long[] dimSizesN = new long[(int)CDF_MAX_DIMS];
             numDimsN = 0;
             for (i = 0; i < numDims; i++) {
@@ -748,6 +748,7 @@ private static long numDimsN;
                 ++numDimsN;
               }
             }
+
             JsonObjectBuilder nd = Json.createObjectBuilder().
                                         add("NumDims",numDimsN);
             infos.add (nd.build());
@@ -978,7 +979,7 @@ private static long numDimsN;
             long[]  dimSizes = {1L}, dimVariances;
             long[]  dimIndices   = {0L};
             long[]  dimIntervals = {1L};
-//            long numDimsN = 0;
+            long numDimsN = 0;
             long[] dimSizesN = null;
             maxRec = v.getMaxWrittenRecord();
 
@@ -997,7 +998,6 @@ private static long numDimsN;
             dataType     = v.getDataType();
             dimVariances = v.getDimVariances();
             numValuesToRead = 1;
-/*
             if (numDims > 0) {
                 dimIntervals = new long[dimSizes.length];
                 dimIndices   = new long[dimSizes.length];
@@ -1015,24 +1015,6 @@ private static long numDimsN;
                      numValuesToRead *= dimSizes[i];
                 }
             }
-*/
-            if (numDimsN > 0) {
-                dimIntervals = new long[(int)numDimsN];
-                dimIndices   = new long[(int)numDimsN];
-                dimSizesN    = new long[(int)numDimsN];
-                int j = 0;
-//                numDimsN = 0;
-                for (int i=0; i < numDimsN; i++) {
-                     if (dimVariances[i] == VARY) {
-//                       ++numDimsN;
-                       dimSizesN[j] = dimSizes[i];
-                       ++j;
-                     }
-                     dimIntervals[i] = 1;
-                     dimIndices[i]   = 0;
-                     numValuesToRead *= dimSizes[i];
-                }
-            }
 
             JsonArrayBuilder records = Json.createArrayBuilder();
 
@@ -1058,16 +1040,15 @@ private static long numDimsN;
                      numRecordsToRead = maxRec - i + 1;
                  else
                      numRecordsToRead = incrementCounter; 
-                 if (numDimsN > 0) {
+                 if (numDimsN > 0)
                      cdfdata = v.getHyperDataObject((long) i, 
                                                     numRecordsToRead, 1L,
                                                     dimIndices,
                                                     dimSizes,
                                                     dimIntervals);
-                 } else {
+                 else 
                      cdfdata = v.getRecordsObject((long) i,
                                                    numRecordsToRead);
-                 }
                  // Get the status of the last CDF call
                  long status = cdf.getStatus();
                  Object dataArray = cdfdata.getData();
@@ -1087,7 +1068,7 @@ private static long numDimsN;
                       } else 
                           datum = dataArray;
 
-                      if (numDimsN > 0 && numDims != numDimsN) {
+                      if (numDims != numDimsN) {
                         // Filled data for non-varying dimension(s)
                         long iz;
                         iz = numDims;
@@ -1096,7 +1077,6 @@ private static long numDimsN;
                           --iz;
                         }
                       }
-
                       if (numDimsN < 2) {
                         boolean single = false;
                         if (!recVary || maxRec == 0) single = true;
@@ -1105,7 +1085,7 @@ private static long numDimsN;
                                                     datum, dataType, numDimsN,
                                                     -1, (withz?"Z":""), formatT,
                                                     fillVal, single);
-                      } else {
+                      } else { 
                          JsonArrayBuilder oData = printMultipleData (datum,
                                                     dataType, (int)numDimsN,
                                                     dimSizes,
