@@ -315,7 +315,7 @@ public class EditgEntryTablePanel extends JPanel implements CDFConstants {
 
         void checkNumElem(Object newone, int row) {
             String dataType = (String) getValueAt(row, 1);
-            if (dataType.equals("CDF_CHAR") && dataType.equals("CDF_UCHAR"))
+            if (dataType.equals("CDF_CHAR") || dataType.equals("CDF_UCHAR"))
               dataObject[row][2] = "" + ((String)newone).length();
             else
               dataObject[row][2] = "1";
