@@ -459,13 +459,13 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
                       StringBuffer tmpStr = new StringBuffer();
                       for (int i = 0; i < ((double[])value).length; i++) {
                         if (i > 0) tmpStr.append(", ");
-                        String tmp = Epoch.encode(((double[])value)[i]);
+                        String tmp = Epoch.encode4(((double[])value)[i]);
                         tmpStr.append(tmp);
                       }
 //                      tmpStr.setLength(tmpStr.length()-2);
                       dataObject[jj][2] = tmpStr.toString();
                     } else
-                      dataObject[jj][2] = Epoch.encode(((Double)value).doubleValue());
+                      dataObject[jj][2] = Epoch.encode4(((Double)value).doubleValue());
                   } else if (dataType == CDF_EPOCH16) {
                     if (value.getClass().getName().indexOf('[') == 0) { // an array
                       StringBuffer tmpStr = new StringBuffer();
@@ -474,7 +474,7 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
                         if (i > 0) tmpStr.append(", ");
 			mmm[0] = ((double[])value)[i];
 			mmm[1] = ((double[])value)[i+1];
-                        String tmp = Epoch16.encode(mmm);
+                        String tmp = Epoch16.encode4(mmm);
                         tmpStr.append(tmp);
                       }
 //                      tmpStr.setLength(tmpStr.length()-2);
@@ -492,8 +492,17 @@ public class EditvAttributeTableScrollPane extends JScrollPane implements TableM
                       dataObject[jj][2] = tmpStr.toString();
                     } else
                       dataObject[jj][2] = CDFTT2000.toUTCstring(((Long)value).longValue());
-                  } else
-	             dataObject[jj][2] = CDFUtils.getStringData(value, ", ");
+                  } else {
+                    if (dataType == CDF_REAL4 || dataType == CDF_REAL8 ||
+                        dataType == CDF_FLOAT || dataType == CDF_DOUBLE) {
+                      String format;
+                      try {
+                        format = (String) cdf.getVariable(varName).getEntryData("FORMAT");
+                      } catch (CDFException ce) { format = null; }
+                      dataObject[jj][2] = CDFUtils.getStringFloatingData (value, format, ", ").trim();
+                    } else
+                      dataObject[jj][2] = CDFUtils.getStringData(value, ", ");
+                  }
 		} catch (CDFException ex) { System.out.println("error..."+ex);}
 	      }
 	    }
