@@ -8,6 +8,7 @@ package gsfc.nssdc.cdf;
 
 import java.util.*;
 import java.io.File;
+import java.nio.charset.*;
 import java.lang.reflect.*;
 import gsfc.nssdc.cdf.util.*;
 
@@ -211,7 +212,9 @@ synchronized(myAttribute) {
 
 	theEntry.myAttribute.getMyCDF().
 	    executeCommand((CDFObject)theEntry, cmds);
+
 	myAttribute.addEntry(theEntry, (int)id);
+
 	return theEntry;
     }
 }
@@ -328,17 +331,39 @@ synchronized(myAttribute) {
             itemC.addElement("J");
           cmds.addElement(itemC);
 
-          if (theEntry.scope == VARIABLE_SCOPE &&
+          if ((theEntry.scope == VARIABLE_SCOPE ||
+               theEntry.scope == GLOBAL_SCOPE) &&
               (dataType == CDF_CHAR || dataType == CDF_UCHAR)) {
             if (CDFUtils.getSignature(data).indexOf("[") != -1) {
-              theEntry.numStrings    = (long) ((String[])data).length;
-              theEntry.data          = (Object) CDFUtils.mergeFromStrings(data);
-              theEntry.numElements   = (long) ((String)(theEntry.data)).length();
-              theEntry.dataSignature = CDFUtils.getSignature(theEntry.data);
+              if (CDFUtils.getSignature(data).indexOf("[B") != -1) {
+                theEntry.data          = data;
+                theEntry.numStrings    = 1;
+                theEntry.numElements   = (long) ((byte[])data).length;
+                theEntry.dataSignature = CDFUtils.getSignature(theEntry.data);
+              } else {
+                theEntry.numStrings    = (long) ((String[])data).length;
+                theEntry.data          = (Object) CDFUtils.mergeFromStrings(data);
+                String oneStr          = (String)(theEntry.data);
+                byte[] bytes;
+                try {
+                  bytes      = oneStr.getBytes("UTF-8");
+                } catch (Exception ee) {
+                  bytes      = oneStr.getBytes();
+                }
+                theEntry.numElements   = (long) bytes.length;
+                theEntry.dataSignature = CDFUtils.getSignature(theEntry.data);
+              }
             } else {
-              theEntry.data          = data;
-	      theEntry.numElements   = CDFUtils.getNumElements(dataType, data);
-              theEntry.numStrings    = (long) CDFUtils.getNumStrings(data);
+              try {
+                byte[] bytes           = ((String)data).getBytes("UTF-8");
+                theEntry.data          = bytes;
+                theEntry.numElements   = bytes.length;
+	      } catch (Exception ee) {
+                theEntry.data          = data;
+		theEntry.numElements   = CDFUtils.getNumElements(dataType,
+                                                                 theEntry.data);
+	      }
+              theEntry.numStrings    = (long) CDFUtils.getNumStrings(theEntry.data);
               theEntry.dataSignature = CDFUtils.getSignature(theEntry.data);
             }
           } else {
@@ -384,6 +409,7 @@ synchronized(myAttribute) {
 	if ((dataType == CDF_CHAR) || (dataType == CDF_UCHAR)) {
 	    data = new String();
 	    dataSignature = "Ljava/lang/String;";
+
 	} else {
 	    switch ((int)dataType) {
 	    case (int)CDF_BYTE:
@@ -577,13 +603,36 @@ synchronized(myAttribute) {
 
       try {
 	if ((dataType == CDF_CHAR) || (dataType == CDF_UCHAR)) {
-            if (scope == GLOBAL_SCOPE)
-	      return new String((String)data.toString());
-            else {
-              if (numStrings < 2)
-                return new String((String)data.toString());
-              else
-                return CDFUtils.breakIntoStrings((String)data.toString());
+            String signature = CDFUtils.getSignature(data);
+            if (scope == GLOBAL_SCOPE) {
+              if (signature.indexOf("[B") != -1) {
+	        try {
+	          return new String((byte[])data, "UTF-8");
+		} catch (Exception ee) {
+	          return new String((byte[])data);
+		}
+              } else {
+                return (String) data;
+	      }
+            } else {
+              if (numStrings < 2) {
+                if (signature.indexOf("[B") != -1) {
+                  return new String((byte[])data, "UTF-8");
+                } else {
+                  String encoding = System.getProperty("file.encoding").
+                                    toUpperCase();
+                  if (encoding.indexOf("UTF-8") == -1 &&
+                      encoding.indexOf("UTF8") == -1)
+                    return (String) data;
+                  else
+                    return new String(((String)data).getBytes(), "UTF-8");
+                }
+              } else {
+                if (signature.indexOf("[B") != -1) {
+                  return CDFUtils.breakIntoStrings(new String((byte[])data));
+                } else
+                  return CDFUtils.breakIntoStrings((String)data.toString());
+              }
             }
 	} else {
 	  switch ((int)dataType) {
@@ -668,7 +717,10 @@ synchronized(myAttribute) {
 	  }
 	}
 	return null;
-      } catch (Exception ex) {throw new CDFException(DATATYPE_MISMATCH);}
+      } catch (Exception ex) {
+        System.out.println("*** EXCEPTION: "+ex);
+        throw new CDFException(DATATYPE_MISMATCH);
+      }
     }
 	
     /**
@@ -836,21 +888,32 @@ synchronized(myAttribute) {
               itemC.addElement("J");
             cmds.addElement(itemC);
             
-          if (this.scope == VARIABLE_SCOPE &&
+          if ((this.scope == VARIABLE_SCOPE || this.scope == GLOBAL_SCOPE) &&
               (dataType == CDF_CHAR || dataType == CDF_UCHAR)) {
             if (CDFUtils.getSignature(data).indexOf("[") != -1) {
               this.numStrings    = (long) ((String[])data).length;
               this.data         = (Object) CDFUtils.mergeFromStrings(data);
-              this.numElements   = (long) ((String)(this.data)).length();
+              String oneStr     = (String)(this.data);
+              byte[] bytes;
+              try {
+                bytes      = oneStr.getBytes("UTF-8");
+              } catch (Exception ee) {
+                bytes      = oneStr.getBytes();
+              }
+              this.numElements   = (long) bytes.length;
               this.dataSignature = CDFUtils.getSignature(this.data);
             } else {
-              this.data         = data;
-              this.numElements   = CDFUtils.getNumElements(dataType, data);
-              this.numStrings    = (long) CDFUtils.getNumStrings(data);
+	      try {
+                this.data          = new String(((String)data).getBytes(), "UTF-8");
+	      } catch (Exception ee) {
+                this.data          = data;
+	      }
+              this.numElements   = CDFUtils.getNumElements(dataType, this.data);
+              this.numStrings    = (long) CDFUtils.getNumStrings(this.data);
               this.dataSignature = CDFUtils.getSignature(this.data);
             }
           } else {
-            this.data         = data;
+            this.data          = data;
             this.numElements   = CDFUtils.getNumElements(dataType, data);
             this.numStrings    = 1;
             this.dataSignature = CDFUtils.getSignature(this.data);
